/*
 * Copyright (c) 2011, Andreas Spall
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted provided that the following conditions are met:
 *
 * - Redistributions of source code must retain the above copyright notice, 
 *   this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright notice, 
 *   this list of conditions and the following disclaimer in the documentation 
 *   and/or other materials provided with the distribution.
 * - Neither the name of Andreas Spall nor the names of its contributors 
 *   may be used to endorse or promote products derived from this software 
 *   without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF 
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.osoboo.jira.metadata.ui.internal;

import java.util.Map;

import com.atlassian.jira.plugin.projectpanel.impl.GenericProjectTabPanel;
import com.atlassian.jira.project.browse.BrowseContext;
import com.atlassian.jira.security.JiraAuthenticationContext;
import com.atlassian.jira.security.PermissionManager;
import com.atlassian.jira.util.JiraVelocityUtils;
import com.atlassian.jira.web.bean.I18nBean;
import com.osoboo.jira.metadata.MetadataService;

/**
 * the project metadata panel adds the meta data service, and the result of the
 * check if user is project admin to the velocity parameter list.
 * 
 * @author aspall
 * 
 */
public class ProjectMetadataPanel extends GenericProjectTabPanel {

	private MetadataService metadataService;
	/** used to check the current users permission to edit the metadata. */
	private final PermissionManager permissionManager;
	/** the project admin permission key. */
	private final int PROJECT_ADMIN = 23;

	public ProjectMetadataPanel(PermissionManager permissionManager, JiraAuthenticationContext jiraAuthenticationContext,
			MetadataService metadataService) {
		super(jiraAuthenticationContext);
		this.permissionManager = permissionManager;
		this.metadataService = metadataService;
	}

	@Override
	public String getHtml(BrowseContext ctx) {
		final Map<String, Object> params = JiraVelocityUtils.getDefaultVelocityParams(authenticationContext);
		params.put("i18n", new I18nBean(ctx.getUser()));
		params.put("project", ctx.getProject());
		try {
			params.put("hasAdminPermission",
					permissionManager.hasPermission(PROJECT_ADMIN, ctx.getProject(), authenticationContext.getLoggedInUser()));
		} catch (NoSuchMethodError e) {
			params.put("hasAdminPermission",
					permissionManager.hasPermission(PROJECT_ADMIN, ctx.getProject(), authenticationContext.getUser()));

		}
		params.put("metadataService", metadataService);
		return descriptor.getHtml("view", params);
	}

}
